@@ -26,11 +26,10 @@ where
     WriteError(<S as Write<u8>>::Error),
     FormatError(fmt::Error),
     BadInputError(Utf8Error),
-    HistoryError(()),
+    HistoryError,
 }
 
 pub enum Input<'a> {
     Raw(u8),
-    Control(u8),
     Command(u8, &'a str),
 }
